﻿using EPiServer.Core;
using FotoWare.PlugIns.Episerver.Interfaces;
using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Configuration;
using System.Linq;

namespace FotoWare.PlugIns.Episerver
{
    public class ExampleSiteOneFotoWareSettings : IFotoWareSettings
    {
        public ExampleSiteOneFotoWareSettings()
        {
            MetadataConfiguration = new NameValueCollection
            {
                {"5", "Name"},
                {"25", "Keywords"},
                {"80", "Photographers"},
                {"116", "Copyright"},
                {"120", "Description"}
            };
        }

        public virtual string AllowedTypes => ConfigurationManager.AppSettings["FotoWare:AllowedTypes"]?? ".jpg,.jpeg,.jpe,.gif,.bmp,.png";

        public virtual string ClientId => ConfigurationManager.AppSettings["FotoWare:ClientId"];

        public virtual string ClientSecret => ConfigurationManager.AppSettings["FotoWare:ClientSecret"];

        public virtual string ServerClientId => ConfigurationManager.AppSettings["FotoWare:ServerApi:ClientId"];

        public virtual string ServerClientSecret => ConfigurationManager.AppSettings["FotoWare:ServerApi:ClientSecret"];

        public string ServerAccessToken { get; set; }

        public DateTime ServerAccessTokenExpireTime { get; set; }

        public virtual string FotoWareTenantUrl => ConfigurationManager.AppSettings["FotoWare:TenantUrl"];

        /// <summary>
        /// Used in sheduled Job for full import, not MultiSiteSupport
        /// </summary>       
        public virtual IEnumerable<string> ArchiveUrlsToSynchronize
        {
            get
            {
               var archives = ConfigurationManager.AppSettings["FotoWare:ArchiveUrlsToSynchronize"];
               if (!string.IsNullOrWhiteSpace(archives))
               {
                   return archives.Split(',');
               }

               return Enumerable.Empty<string>();
            }
        }


        public virtual NameValueCollection MetadataConfiguration { get; set; }

        public virtual int PreferredDownloadWidth
        {
            get
            {
                if (!int.TryParse(ConfigurationManager.AppSettings["FotoWare:PreferredDownloadWidth"], out int size))
                {
                    size = 0;
                }

                return size;
            }
        }

        public virtual string PresetUrl => ConfigurationManager.AppSettings["FotoWare:PresetUrl"];

        public virtual string RedirectUri => ConfigurationManager.AppSettings["FotoWare:RedirectUri"];

        public virtual bool UseOauth => ServerClientId != null && ServerClientSecret != null;


        public virtual ContentReference RootFolderId

        {
            get
            {
                if (!int.TryParse(ConfigurationManager.AppSettings["FotoWare:RootFolderId"], out int id))
                {
                    throw new Exception("FotoWare configuration not complete, FotoWare:RootFolderId in appsettings web.config not set to a valid folder id");
                }
                return new ContentReference(ConfigurationManager.AppSettings["FotoWare:RootFolderId"]);
            }
        }

        public virtual bool DisableEpiserverDefaultMediaSelector
        {
            get
            {
                if (!bool.TryParse(ConfigurationManager.AppSettings["FotoWare:DisableEpiserverDefaultMediaSelector"], out bool value))
                {
                    value = false;
                }

                return value;
            }
        }

        public virtual bool EnableOnAllImages
        {
            get
            {
                if (!bool.TryParse(ConfigurationManager.AppSettings["FotoWare:EnableOnAllImages"], out bool value))
                {
                    value = true;
                }

                return value;
            }
        }

        public virtual bool ExportWidgetEnableOnAllImages
        {
            get
            {
                if (!bool.TryParse(ConfigurationManager.AppSettings["FotoWare:ExportWidgetEnableOnAllImages"], out bool value))
                {
                    value = true;
                }

                return value;
            }
        }
    }
}